@@ -2,53 +2,24 @@ import logging
 import os
 import sys
 import tempfile
-from collections import Counter, namedtuple
 
 from pyvis.network import Network
-from scapy.layers.inet import IP, Ether
-from scapy.utils import PcapReader
 
+from plotcap.api import parse_file
 from plotcap.mac_address import get_manufacturer_name
 
 logger = logging.getLogger(__name__)
 
 
-def plot_network(
-    pcap_file: str, layer: str = "layer2", resolve_oui: bool = True
-):
+def plot_network(pcap_file: str, layer: int = 2, resolve_oui: bool = True):
     """
     Build a summary of conversations:
     source MAC/IP address, destination/IP MAC address, number of packets
     """
-    if layer == "layer2":
-        ip_layer = Ether
-    elif layer == "layer3":
-        ip_layer = IP
-    conversations = Counter()
-    ConversationPair = namedtuple("ConversationPair", ["src", "dst"])
-    bytes_read: int = 0
-    with PcapReader(pcap_file) as pcap_reader:
-        for packet_counter, packet in enumerate(pcap_reader, start=1):
-            bytes_read += packet.wirelen
-            if ip_layer in packet:
-                logger.debug(
-                    f"Packet {packet_counter} - Source: {packet[ip_layer].src}, Destination: {packet[ip_layer].dst} - Frame length: {packet[ip_layer].wirelen}"
-                )
-                # count conversations as tuples! (trailing comma is required)
-                if (
-                    packet[ip_layer].src != "ff:ff:ff:ff:ff:ff"
-                    and packet[ip_layer].dst != "ff:ff:ff:ff:ff:ff"
-                ):
-                    conversations.update(
-                        (
-                            ConversationPair(
-                                src=packet[ip_layer].src,
-                                dst=packet[ip_layer].dst,
-                            ),
-                        )
-                    )
-    logger.info(f"Number of packets read: {packet_counter}")
-    logger.info(f"Number of bytes read: {bytes_read}")
+
+    conversations = parse_file(pcap_file=pcap_file, layer=layer)
+    packet_counter = sum(conversations.values())
+    logger.debug(f"NUmber of packets: {packet_counter}")
 
     nt = Network(height="750px", width="100%", directed=True, filter_menu=True)
 
@@ -85,7 +56,7 @@ def plot_network(
 
     # add edges between nodes, both ways
     for conversation, packet_count in conversations.items():
-        packet_ratio = (packet_count / packet_counter) * 100
+        packet_ratio = (packet_count / len(conversations)) * 100
         logger.debug(
             f"{conversation.src} to {conversation.dst}  - packet_count: {packet_count} - ratio = {packet_ratio}"
         )
@@ -121,12 +92,8 @@ def plot_network(
 
 
 def plot_layer2(pcap_file: str, resolve_oui: bool = True):
-    return plot_network(
-        pcap_file=pcap_file, layer="layer2", resolve_oui=resolve_oui
-    )
+    return plot_network(pcap_file=pcap_file, layer=2, resolve_oui=resolve_oui)
 
 
 def plot_layer3(pcap_file: str, resolve_oui: bool = True):
-    return plot_network(
-        pcap_file=pcap_file, layer="layer3", resolve_oui=resolve_oui
-    )
+    return plot_network(pcap_file=pcap_file, layer=3, resolve_oui=resolve_oui)
